# Структура базы данных
## Обзор
Структура базы следующая:
```bash
data/
├── eos
│   ├── comp
│   │   ├── brusylovsky.csv
│   │   └── ...
│   └── mix
│       ├── brusylovsky.csv
│       ├── pr.csv
│       └── ...
├── phys
│   ├── comp
│   │   ├── martinez.csv
│   │   └── ...
│   └── mix
│       └── ...
├── README.md
└── src
    ├── gas-parameters-martinez.pdf
    └── ...
```
Предназначение директорий, их содержание:
- `eos/comp/` - параметры уравнения состояния чистого компонента. Например, в случае уравнения состояния Брусиловского это $`z^\ast_C, \Omega_C, \psi`$;
- `eos/mix/` - параметры температурной квадратичной зависимости коэффициентов парного взаимодействия для каждого уравнения состояния;
- `phys/comp/` - физические параметры веществ. Содержит разные базы данных;
- `phys/mix/` - пока не определена. Вероятно, отведена будет под хранение экспериментальных данных.
- `src/` - не затрагивается кодом, здесь лежат некоторые исходники, ссылки на данные.

# Формат файлов БД

## Уравнение состояния

### Чистый компонент `eos/comp/*.csv`
Поля файла:
```bash
name,critical_compressibility,critical_omega,psi
```
Название компонента, параметры по Брусиловскому: $`z^\ast_C, \Omega_C, \psi`$.

Для **каждого** параметра, загружаемого по эмпирической зависимости для группы `С5+высшие`
требуется указать значение конфигурационной константы для этой группы веществ.
Она объявлена в `Database/src/config.jl` -> `LOADASC5`.
Например, если `LOADASC5 = "C5+"` и требуется загрузить все три параметра н-октана
по эмпирической зависимости, то компонент вносится в файл БД строкой:
```bash
n-octane,C5+,C5+,C5+
```

В случае уравнений состояния с постоянными параметрами (PR, SRK), вероятно, просто в код включим.

### Смесь `eos/mix/*.csv`
Поля файла:
```bash
comp1,comp2,constant,linear,quadratic
```
Два названия компонентов, постоянный коэффициент зависимости от температуры, линейный и квадратичный.

## Физические параметры

### Чистый компонент `phys/comp/*.csv`
Поля файла:
```bash
name,molecular_mass,critical_temperature,critical_pressure,acentric_factor,critical_compressibility
```
Имя компонента, молярная масса (кг/мол), критическая температура (К), критическое давление (Па), ацентрический фактор Питцера, критическая сверхсжимаемость.

### Смесь `phys/mix/*.csv`
Пока неизвестно...
